package com.tencent.ticsdk.demo;

import android.content.Context;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONTokener;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.HashMap;

/**
 * Created by Ericczhuang on 2018/8/30.
 */
public class ConfigInfo {
    private static ConfigInfo instance = null;

    private boolean mConfigLoad;
    private int mSdkAppId;
    private HashMap<String, String> mUserMap;
    //    private HashMap<String, String> mRoleMap;
    private String classId;

    private ConfigInfo() {
        mConfigLoad = false;
        mSdkAppId = 0;
        mUserMap = new HashMap<>();
    }

    public static ConfigInfo getInstance() {
        if (null == instance) {
            instance = new ConfigInfo();
        }
        return instance;
    }

    /*** 加载配置文件 */
    public void loadConfig(Context context, int resId) throws Exception {
        InputStream is = context.getResources().openRawResource(resId);
        String jsonData = readTextFromInputStream(is);
        loadJsonData(jsonData);
        mConfigLoad = true;
    }

    public void loadConfig(Context context) throws Exception {
        loadConfig(context, R.raw.config);
    }

    /**
     * 判断配置是否加载成功
     */
    public boolean isConfigLoad() {
        return mConfigLoad;
    }

    public void setmConfigLoad(boolean mConfigLoad) {
        this.mConfigLoad = mConfigLoad;
    }

    /**
     * 在配置文件中获取SDKAPPID
     */
    public int getSdkAppId() {
        return mSdkAppId;
    }

    /**
     * 在配置文件中获取用户登录信息
     */
    public HashMap<String, String> getUserMap() {
        return mUserMap;
    }

    public String getClassId() {
        return classId;
    }

    /**
     * 读取资源文件
     */
    private String readTextFromInputStream(InputStream is) throws Exception {
        InputStreamReader reader = new InputStreamReader(is);
        BufferedReader bufferedReader = new BufferedReader(reader);
        StringBuffer buffer = new StringBuffer("");
        String str;
        while (null != (str = bufferedReader.readLine())) {
            buffer.append(str);
            buffer.append("\n");
        }
        return buffer.toString();
    }

    /**
     * 解析JSON配置文件
     */
    private void loadJsonData(String jsonData) throws Exception {
        JSONTokener jsonTokener = new JSONTokener(jsonData);
        JSONObject msgJson = (JSONObject) jsonTokener.nextValue();
        mSdkAppId = msgJson.getInt("sdkappid");
        Constants.APPID = mSdkAppId;

        JSONArray jsonUsersArr = msgJson.getJSONArray("users");
        if (null != jsonUsersArr) {
            for (int i = 0; i < jsonUsersArr.length(); i++) {
                JSONObject jsonUser = jsonUsersArr.getJSONObject(i);
                // debug，截取appid信息用于课堂id
                if (i == 0) {
                    String userId = jsonUser.getString("userId");
                    String[] userInfo = userId.split("_");
                    classId = userInfo[1];
                }
                mUserMap.put(jsonUser.getString("userId"),
                        jsonUser.getString("userToken"));
            }
        }
    }
}
