package com.tencent.ticsdk.demo.activities;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.provider.MediaStore;
import android.support.annotation.Nullable;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.ToggleButton;

import com.tencent.TIMElem;
import com.tencent.TIMFaceElem;
import com.tencent.TIMFileElem;
import com.tencent.TIMLocationElem;
import com.tencent.TIMMessage;
import com.tencent.TIMSoundElem;
import com.tencent.TIMUserStatusListener;
import com.tencent.av.sdk.AVContext;
import com.tencent.boardsdk.board.IWbCallBack;
import com.tencent.boardsdk.board.IWbProgressCallBack;
import com.tencent.boardsdk.board.WhiteboardManager;
import com.tencent.boardsdk.board.WhiteboardView;
import com.tencent.boardsdk.config.TextConfig;
import com.tencent.boardsdk.file.FileInfo;
import com.tencent.ilivesdk.ILiveCallBack;
import com.tencent.ilivesdk.ILiveFunc;
import com.tencent.ilivesdk.core.ILiveLoginManager;
import com.tencent.ilivesdk.core.ILiveRoomManager;
import com.tencent.ilivesdk.tools.quality.ILiveQualityData;
import com.tencent.ilivesdk.tools.quality.LiveInfo;
import com.tencent.ticsdk.TICManager;
import com.tencent.ticsdk.demo.ClassInfo;
import com.tencent.ticsdk.demo.Constants;
import com.tencent.ticsdk.demo.R;
import com.tencent.ticsdk.demo.observer.ClassEventObservable;
import com.tencent.ticsdk.demo.observer.ClassroomIMObservable;
import com.tencent.ticsdk.demo.observer.UserStatusObservable;
import com.tencent.ticsdk.demo.utils.Utils;
import com.tencent.ticsdk.demo.views.LivingVideoView;
import com.tencent.ticsdk.demo.widgets.FileOperationBar;
import com.tencent.ticsdk.demo.widgets.FilePickerDialog;
import com.tencent.ticsdk.demo.widgets.WhiteboardToolBar;
import com.tencent.ticsdk.listener.IClassEventListener;
import com.tencent.ticsdk.listener.IClassroomIMListener;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * Created by eric on 2018/5/14.
 */

public class ClassroomActivity extends BaseActvity implements View.OnClickListener, CompoundButton.OnCheckedChangeListener,
        IClassroomIMListener, IClassEventListener, TIMUserStatusListener {
    private final static String TAG = "ClassroomActivity";

    /**
     * 白板视图控件
     */
    WhiteboardView whiteboardView;

    /**
     * 实时音视频视图控件，继承于AvRootView
     */
    LivingVideoView livingVideoView;

    /**
     * 白板控制工具条控件
     */
    WhiteboardToolBar whiteboardToolBar;

    /**
     * 文件操作工具条
     */
    FileOperationBar fileOperationBar;
    /**
     * 课堂ID显示控件
     */
    TextView tvClassIdInfo;

    /**
     *
     */
    ToggleButton tbSwither, tbWbEnableSwitcher, tbShowSystemStatus, tbScale;

    // 课堂管理

    Button btnSend;
    EditText etMessageInput;

    private static final int CROP_CHOOSE = 10;

    private Uri fileUri, cropUri;

    private Handler mainHandler = new Handler(Looper.getMainLooper());

    private Runnable infoRun = new Runnable() {
        @Override
        public void run() {
            ILiveQualityData qualityData = ILiveRoomManager.getInstance().getQualityData();
            if (null != qualityData) {
                String info = "AVSDK 版本: \t" + AVContext.sdkVersion + "\n\n"
                        + "上行速率:\t" + qualityData.getSendKbps() + "kbps\t"
                        + "上行丢包率:\t" + qualityData.getSendLossRate() / 100 + "%\n\n"
                        + "下行速率:\t" + qualityData.getRecvKbps() + "kbps\t"
                        + "下行丢包率:\t" + qualityData.getRecvLossRate() / 100 + "%\n\n"
                        + "应用CPU:\t" + qualityData.getAppCPURate() + "\t"
                        + "系统CPU:\t" + qualityData.getSysCPURate() + "\n\n";
                for (Map.Entry<String, LiveInfo> entry : qualityData.getLives().entrySet()) {
                    info += "\t" + entry.getKey() + "-" + entry.getValue().getWidth() + "*" + entry.getValue().getHeight() + "\n\n";
                }
                ((TextView) findViewById(R.id.status_info)).setText(info);
            }
            if (ILiveRoomManager.getInstance().isEnterRoom()) {
                if (tbShowSystemStatus.isChecked()) {
                    mainHandler.postDelayed(infoRun, 2000);
                } else {
                    ((TextView) findViewById(R.id.status_info)).setText("");
                }
            }
        }
    };

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        ClassEventObservable.getInstance().addObserver(this);
        ClassroomIMObservable.getInstance().addObserver(this);
        UserStatusObservable.getInstance().addObserver(this);

        tvLog = findViewById(R.id.tv_log);
        checkCameraAndMicPermission();

        WhiteboardManager.getInstance().getConfig()
                .setTimePeriod(300)
                .setPaintSize(6)
                .setFontStyle(TextConfig.TEXT_STYLE_NORMAL)
                .setPaintColor(Color.BLUE)
                .setUserId(ClassInfo.getInstance().getUserid());

        whiteboardView = findViewById(R.id.whiteboardview);
        whiteboardView.setWhiteboardEnable(true);

        // 白板视图跟iLIveSDK视频渲染视图叠加显示时，务必设置该参数。
        whiteboardView.setZOrderMediaOverlay(true);

        whiteboardToolBar = findViewById(R.id.ll_whiteboard_tool_bar);
        whiteboardToolBar.setFilePickerClickListener(new WhiteboardToolBar.FilePickerClickListener() {
            @Override
            public void onFilePickerClick(int type) {
                getFileByType(type);
            }
        });

        fileOperationBar = findViewById(R.id.file_operation_bar);

        livingVideoView = findViewById(R.id.av_root_view);
        livingVideoView.setLocalFullScreen(false);

        TICManager.getInstance().setAvRootView(livingVideoView);

        tvClassIdInfo = findViewById(R.id.tv_classId);

        tbSwither = findViewById(R.id.tb_switcher);
        tbSwither.setOnCheckedChangeListener(this);

        tbShowSystemStatus = findViewById(R.id.tb_show_system_status);
        tbShowSystemStatus.setOnCheckedChangeListener(this);

        tbWbEnableSwitcher = findViewById(R.id.tb_whiteboard_swither);
        tbWbEnableSwitcher.setOnCheckedChangeListener(this);

        tbScale = findViewById(R.id.tb_scale);
        tbScale.setOnCheckedChangeListener(this);


        etMessageInput = findViewById(R.id.et_message_input);

        btnSend = findViewById(R.id.btn_send);
        btnSend.setOnClickListener(this);

        findViewById(R.id.btn_c2c_text_send).setOnClickListener(this);
        findViewById(R.id.btn_c2c_custom_send).setOnClickListener(this);
        findViewById(R.id.btn_custom_send).setOnClickListener(this);
        findViewById(R.id.btn_face_send).setOnClickListener(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        tvClassIdInfo.setText("当前课堂ID: " + ClassInfo.getInstance().getClassId());
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        ClassEventObservable.getInstance().deleteObserver(this);
        ClassroomIMObservable.getInstance().deleteObserver(this);
        UserStatusObservable.getInstance().deleteObserver(this);
    }

    @Override
    public void onBackPressed() {
        onQuitClsssroomClick(null);
    }

    private void getFileByType(int type) {
        switch (type) {
            case FilePickerDialog.REQUEST_CAPTURE_IMAGE_CAMERA:
                fileUri = createCoverUri("", false);
                Intent intent_photo = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
                intent_photo.putExtra(MediaStore.EXTRA_OUTPUT, fileUri);
                startActivityForResult(intent_photo, FilePickerDialog.REQUEST_CAPTURE_IMAGE_CAMERA);
                break;
            case FilePickerDialog.REQUEST_IMAGE_STORE:
                fileUri = createCoverUri("_select", false);
                Intent intent_album = new Intent("android.intent.action.GET_CONTENT");
                intent_album.setType("image/*");
                startActivityForResult(intent_album, FilePickerDialog.REQUEST_IMAGE_STORE);
                break;
            case FilePickerDialog.REQUEST_DOCUMENT_STORE:
                String[] mimeTypes =
                        {
                                "application/pdf",
                                "application/msword",
                                "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
                                "application/vnd.ms-powerpoint",
                                "application/vnd.openxmlformats-officedocument.presentationml.presentation",
                                "application/vnd.ms-excel",
                                "application/application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
                                "text/plain"
                        };

                Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
                intent.addCategory(Intent.CATEGORY_OPENABLE);

                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
                    intent.setType(mimeTypes.length == 1 ? mimeTypes[0] : "*/*");
                    if (mimeTypes.length > 0) {
                        intent.putExtra(Intent.EXTRA_MIME_TYPES, mimeTypes);
                    }
                } else {
                    String mimeTypesStr = "";
                    for (String mimeType : mimeTypes) {
                        mimeTypesStr += mimeType + "|";
                    }
                    intent.setType(mimeTypesStr.substring(0, mimeTypesStr.length() - 1));
                }
                startActivityForResult(Intent.createChooser(intent, "ChooseFile"), FilePickerDialog.REQUEST_DOCUMENT_STORE);
//                Intent i = new Intent();
//                i.setAction(Intent.ACTION_GET_CONTENT);
//                i.setType("*/*");
//                startActivityForResult(i, FilePickerDialog.REQUEST_DOCUMENT_STORE);
                break;
        }
    }

    private Uri createCoverUri(String type, boolean bCrop) {
        String filename = ILiveLoginManager.getInstance().getMyUserId() + "_" + System.currentTimeMillis() + ".jpg";
        File outputImage = new File(Environment.getExternalStorageDirectory(), filename);
        try {
            if (outputImage.exists()) {
                outputImage.delete();
            }
            outputImage.createNewFile();
        } catch (IOException e) {
            e.printStackTrace();
        }

        if (bCrop) {
            return Uri.fromFile(outputImage);
        } else {
            return Utils.getUriFromFile(this, outputImage);
        }
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
        boolean on = buttonView.isChecked();
        switch (buttonView.getId()) {
            case R.id.tb_switcher:
                if (on) {
                    whiteboardView.setVisibility(View.VISIBLE);
                    livingVideoView.setVisibility(View.INVISIBLE);
                } else {
                    whiteboardView.setVisibility(View.INVISIBLE);
                    livingVideoView.setVisibility(View.VISIBLE);
                }
                break;
            case R.id.tb_whiteboard_swither:
                whiteboardView.setWhiteboardEnable(on);
                break;
            case R.id.tb_scale:
                tbWbEnableSwitcher.setChecked(true);
                whiteboardView.setDragEnable(on);
                break;
            case R.id.tb_show_system_status:
                if (on) {
                    mainHandler.post(infoRun);
                } else {
                    mainHandler.removeCallbacksAndMessages(0);
                    ((TextView) findViewById(R.id.status_info)).setText("");
                }
                break;
        }
    }

    /**
     * 退出课堂
     */
    public void onQuitClsssroomClick(View v) {
        if (!Constants.check(this)) {
            postToast("请检查Constants里的配置是否已经填写完整。");
            return;
        }
        TICManager.getInstance().quitClassroom(new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                postToast("quitClassroom#onSuccess: " + data, true);
                finish();
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("quitClassroom#onError: errCode = " + errCode + "  description " + errMsg);
                finish();
            }
        });
    }

    boolean flag = false;

    public void onAspectRatioClick(View v) {
//        if (flag) {
        //whiteboardView.setAspectRatio(9.0f / 16.0f);
//            flag = false;
//        } else {
        //whiteboardView.setAspectRatio(3.0f / 4.0f);
//            flag = true;
//        }
    }

    boolean isDragAble = false;

    public void onFullScreenClick(View v) {
        if (ILiveFunc.isLandScape(this)) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
        }
    }

    public void onStartRecordingClick(View v) {
//        TICManager.getInstance().startRecord(classId, new ILiveCallBack() {
//            @Override
//            public void onSuccess(Object data) {
//                postToast("startRecord#onSuccess: " + data);
//            }
//
//            @Override
//            public void onError(String module, int errCode, String errMsg) {
//                postToast("startRecord#onError: errCode = " + errCode + "  description " + errMsg);
//            }
//        });
    }

    public void onStopRecordingClick(View v) {
//        TICManager.getInstance().startRecord(classId, new ILiveCallBack() {
//            @Override
//            public void onSuccess(Object data) {
//                postToast("startRecord#onSuccess: " + data);
//            }
//
//            @Override
//            public void onError(String module, int errCode, String errMsg) {
//                postToast("startRecord#onError: errCode = " + errCode + "  description " + errMsg);
//            }
//        });

    }

    @Override
    public void onRecvTextMsg(int type, String fromId, String text) {
        if (type == com.tencent.ticsdk.core.Constants.MSG_TYPE_C2C) {
            postToast(String.format("[%s]（C2C）说: %s", fromId, text));
        } else {
            postToast(String.format("[%s]（Group）说: %s", fromId, text));
        }
    }

    @Override
    public void onRecvCustomMsg(int type, String fromId, byte[] data) {
        if (type == com.tencent.ticsdk.core.Constants.MSG_TYPE_C2C) {
            postToast(String.format("[%s]（C2C:Custom）说: %s", fromId, new String(data)));
        } else {
            postToast(String.format("[%s]（Group:Custom）说: %s", fromId, new String(data)));
        }
    }

    @Override
    public void onRecvMessage(TIMMessage message) {
        handleTimElement(message);
    }

    private void handleTimElement(TIMMessage message) {

        for (int i = 0; i < message.getElementCount(); i++) {
            TIMElem elem = message.getElement(i);
            switch (elem.getType()) {
                case Text:
                    postToast("the Text elem.");
                    break;
                case Custom:
                    postToast("the Custom elem.");
                    break;
                case GroupTips:
                    postToast("the GroupTips elem.");
                    continue;
                case Face:
                    TIMFaceElem faceElem = (TIMFaceElem) elem;
                    postToast(String.format("[%s]（Face）说: %s, index: %d", message.getSender(), new String(faceElem.getData()), faceElem.getIndex()));
                    postToast("the Face elem.");
                    break;
                case Image:
                    postToast("the Text elem.");
                    break;
                case Sound:
                    TIMSoundElem soundElem = (TIMSoundElem) elem;
                    postToast(String.format("[%s]（Sound）说: %s", message.getSender(), soundElem.getPath()));
                    postToast("the Sound elem.");
                    break;
                case Video:
                    postToast("the Video elem.");
                    break;
                case File:
                    TIMFileElem fileElem = (TIMFileElem) elem;
                    postToast(String.format("[%s]（File）说: %s", message.getSender(), fileElem.getPath()));
                    postToast("the File elem.");
                    break;
                case Location:
                    TIMLocationElem locationElem = (TIMLocationElem) elem;
                    postToast(String.format("[%s]（Location）说: (%f, %f), at %s", message.getSender(), locationElem.getLatitude(), locationElem.getLongitude(), locationElem.getDesc()));
                    break;
                default:
                    postToast("the other elem.");
                    break;
            }
        }
    }

    @Override
    public void onLiveVideoDisconnect(int errCode, String errMsg) {
    }

    @Override
    public void onRecordTimestampRequest(ILiveCallBack<Long> callBack) {
        if (callBack != null) {
            callBack.onSuccess(System.currentTimeMillis());
        }
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.btn_c2c_text_send:
                onC2CMsgSend(etMessageInput.getText().toString());
                break;
            case R.id.btn_c2c_custom_send:
                onC2CMsgSend(etMessageInput.getText().toString().getBytes());
                break;
            case R.id.btn_send:
                onGroupMsgSend(etMessageInput.getText().toString());
                break;
            case R.id.btn_custom_send:
                onGroupMsgSend(etMessageInput.getText().toString().getBytes());
                break;
            case R.id.btn_face_send:
                onFaceMsgSend(etMessageInput.getText().toString().getBytes());
                onSoundMsgSend();
                onLocationMsgSend();
                onFileMsgSend();
                break;
        }

    }

    private void onC2CMsgSend(final String msg) {
        TICManager.getInstance().sendTextMessage("eric03", msg, new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                postToast("[我]对[eric03]说: " + msg);
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onC2CMsgSend##onError##" + errMsg);

            }
        });
    }

    private void onC2CMsgSend(final byte[] msg) {
        TICManager.getInstance().sendCustomMessage("eric03", msg, new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                postToast("[我]对[eric03`]说: " + new String(msg));
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onC2CMsgSend##onError##" + errMsg);

            }
        });
    }

    private void onGroupMsgSend(final String msg) {
        TICManager.getInstance().sendTextMessage(null, msg, new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                postToast("[我]说: " + msg);
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onGroupMsgSend##onError##" + errMsg);

            }
        });
    }

    private void onGroupMsgSend(final byte[] msg) {
        TICManager.getInstance().sendCustomMessage(null, msg, new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                postToast("[我]说: " + new String(msg));
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onGroupMsgSend##onError##" + errMsg);

            }
        });
    }

    private void onFaceMsgSend(final byte[] msg) {
        //添加表情
        TIMFaceElem elem = new TIMFaceElem();
        elem.setData(msg); //自定义 byte[]
        elem.setIndex(10);   //自定义表情索引

        TIMMessage message = new TIMMessage();
        message.addElement(elem);
        TICManager.getInstance().sendMessage(null, message, new ILiveCallBack<TIMMessage>() {
            @Override
            public void onSuccess(TIMMessage data) {
                postToast("[我]说: face:: " + new String(msg));
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onFaceMsgSend##onError##" + errMsg);
            }
        });
    }

    private void onSoundMsgSend() {
        TIMSoundElem elem = new TIMSoundElem();
        elem.setPath("/sdcard/test/test.txt"); //填写语音文件路径
        elem.setDuration(20);  //填写语音时长

        TIMMessage message = new TIMMessage();
        message.addElement(elem);
        TICManager.getInstance().sendMessage(null, message, new ILiveCallBack<TIMMessage>() {
            @Override
            public void onSuccess(TIMMessage data) {
                postToast("[我]说: sound:: ");
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onSoundMsgSend##onError##" + errMsg);

            }
        });
    }

    private void onLocationMsgSend() {
        //添加位置信息
        TIMLocationElem elem = new TIMLocationElem();
        elem.setLatitude(113.93);   //设置纬度
        elem.setLongitude(22.54);   //设置经度
        elem.setDesc("腾讯大厦");

        TIMMessage message = new TIMMessage();
        message.addElement(elem);

        TICManager.getInstance().sendMessage(null, message, new ILiveCallBack<TIMMessage>() {
            @Override
            public void onSuccess(TIMMessage data) {
                postToast("[我]说: location:: ");
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onLocationMsgSend##onError##" + errMsg);

            }
        });

    }

    private void onFileMsgSend() {
        //添加文件内容
        TIMFileElem elem = new TIMFileElem();
        elem.setPath("/sdcard/test/"); //设置文件路径
        elem.setFileName("text.txt"); //设置消息展示用的文件名称

        TIMMessage message = new TIMMessage();
        message.addElement(elem);
        TICManager.getInstance().sendMessage(null, message, new ILiveCallBack<TIMMessage>() {
            @Override
            public void onSuccess(TIMMessage data) {
                postToast("[我]说: file:: ");
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onFileMsgSend##onError##" + errMsg);
            }
        });
    }

    @Override
    public void onForceOffline() {
        postToast("您已被踢下线，请检查后重新登录");
        TICManager.getInstance().quitClassroom(new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                postToast("onForceOffline##quitClassroom#onSuccess: " + data);
                Intent intent = new Intent(ClassroomActivity.this, LoginActivity.class);
                startActivity(intent);
                finish();
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                postToast("onForceOffline##quitClassroom#onError: errCode = " + errCode + "  description " + errMsg);
            }
        });

    }

    @Override
    public void onUserSigExpired() {

    }

    @Override
    public void onClassroomDestroy() {
        postToast("课堂已销毁");
    }


    @Override
    public void onMemberJoin(List<String> userList) {
        for (String user : userList) {
            postToast(user + " join.", false);
        }
    }

    @Override
    public void onMemberQuit(List<String> userList) {
        for (String user : userList) {
            postToast(user + " quit.", false);
        }
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        //super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == Activity.RESULT_OK) {

            switch (requestCode) {
                case FilePickerDialog.REQUEST_CAPTURE_IMAGE_CAMERA:
                    startPhotoZoom(fileUri);
                    break;
                case FilePickerDialog.REQUEST_IMAGE_STORE:
                    String path = Utils.getPath(this, data.getData());
                    if (null != path) {
                        Log.d(TAG, "startPhotoZoom->path:" + path);
                        File file = new File(path);
                        startPhotoZoom(Utils.getUriFromFile(this, file));
                    }
                    break;
                case CROP_CHOOSE:
                    // cropUri.getPath()
                    WhiteboardManager.getInstance().setBoardBackGround(cropUri.getPath(), true, new IWbCallBack<String>() {

                        @Override
                        public void onSuccess(String data) {
                            postToast("setBoardBackGround->onSuccess:" + data);
                        }

                        @Override
                        public void onError(String module, int errCode, String errMsg) {
                            postToast("setBoardBackGround->onError:" + module + "|" + errCode + "|" + errMsg, true);
                        }
                    });
                    break;
                case FilePickerDialog.REQUEST_DOCUMENT_STORE:
                    String docPath = Utils.getPath(this, data.getData());
                    if (!TextUtils.isEmpty(docPath)) {
                        postToast("addFile->path:" + docPath, true);
                        WhiteboardManager.getInstance().addFile(docPath, new IWbProgressCallBack<FileInfo>() {
                            @Override
                            public void onPrgress(int percent) {
                                postToast("addFile->onPrgress:" + percent);
                            }

                            @Override
                            public void onSuccess(FileInfo data) {
                                postToast("addFile->onSuccess:" + data);
                                ClassroomActivity.this.runOnUiThread(new Runnable() {
                                    @Override
                                    public void run() {
                                        fileOperationBar.updateFileInfo();
                                    }
                                });
                            }

                            @Override
                            public void onError(String module, int errCode, String errMsg) {
                                postToast("addFile->onError:" + errMsg);
                            }
                        });
                    }
                    break;
                default:
                    break;
            }
        }
    }

    public void startPhotoZoom(Uri uri) {
        cropUri = createCoverUri("_crop", true);

        Intent intent = new Intent("com.android.camera.action.CROP");
        /* 这句要记得写：这是申请权限，之前因为没有添加这个，打开裁剪页面时，一直提示“无法修改低于50*50像素的图片”，
      开始还以为是图片的问题呢，结果发现是因为没有添加FLAG_GRANT_READ_URI_PERMISSION。
      如果关联了源码，点开FileProvider的getUriForFile()看看（下面有），注释就写着需要添加权限。
      */
        intent.addFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION | Intent.FLAG_GRANT_WRITE_URI_PERMISSION);
        intent.setDataAndType(uri, "image/*");
        intent.putExtra("crop", "true");
        intent.putExtra("return-data", false);
        intent.putExtra(MediaStore.EXTRA_OUTPUT, cropUri);
        intent.putExtra("outputFormat", Bitmap.CompressFormat.JPEG.toString());
        startActivityForResult(intent, CROP_CHOOSE);
    }
}
