package com.tencent.ticsdk.demo.activities;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.text.TextUtils;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.tencent.TIMUserStatusListener;
import com.tencent.boardsdk.constants.Error;
import com.tencent.ticsdk.demo.ClassInfo;
import com.tencent.ticsdk.demo.Constants;
import com.tencent.ticsdk.demo.R;
import com.tencent.ticsdk.demo.classroom.ClassroomPresenter;
import com.tencent.ticsdk.demo.classroom.ClassroomView;
import com.tencent.ticsdk.demo.observer.UserStatusObservable;
import com.tencent.ticsdk.demo.privateMapKey.PrivateMapKeyPresenter;
import com.tencent.ticsdk.demo.privateMapKey.PrivateMapKeyView;

import java.util.Locale;

public class ClassroomManagerActivity extends BaseActvity implements PrivateMapKeyView, ClassroomView, TIMUserStatusListener {
    // 课堂id
    EditText etRoomIdInput;
    int roomId;
    TextView tvClassInfo;

    PrivateMapKeyPresenter privateMapKeyPresenter;
    ClassroomPresenter classroomPresenter;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_manager_layout);
        tvLog = findViewById(R.id.tv_manager_log);

        etRoomIdInput = findViewById(R.id.et_roomid);
        tvClassInfo = findViewById(R.id.tv_classInfo);

        privateMapKeyPresenter = new PrivateMapKeyPresenter(this);
        classroomPresenter = new ClassroomPresenter(this);
        UserStatusObservable.getInstance().addObserver(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        ClassInfo.getInstance().resumeFromCache(this);
        etRoomIdInput.setText(ClassInfo.getInstance().getClassId());
        tvClassInfo.setText(String.format(Locale.getDefault(), "当前身份： %s", ClassInfo.getInstance().isRoleTeacher() ? "老师" : "学生"));
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        UserStatusObservable.getInstance().deleteObserver(this);
    }

    /**
     * 创建课堂
     */
    public void onCreateClsssroomClick(View v) {

        if (!Constants.check(this)) {
            postToast("请检查Constants里的配置是否已经填写完整。");
            return;
        }
        String inputString = etRoomIdInput.getText().toString().trim();
        if (TextUtils.isEmpty(inputString) || !TextUtils.isDigitsOnly(inputString)) {
            Toast.makeText(this, "invalid room id" + inputString, Toast.LENGTH_SHORT).show();
            return;
        }

        roomId = Integer.valueOf(inputString);
        classroomPresenter.createClassroom(roomId);
    }

    /**
     * 进入课堂
     */
    public void onJoinClsssroomClick(View v) {

        if (!Constants.check(this)) {
            postToast("请检查Constants里的配置是否已经填写完整。");
            return;
        }
        String roomInputId = etRoomIdInput.getText().toString().trim();
        if (TextUtils.isEmpty(roomInputId) || !TextUtils.isDigitsOnly(roomInputId)) {
            Toast.makeText(this, "invalid room id" + roomInputId, Toast.LENGTH_SHORT).show();
            return;
        }

        ClassInfo.getInstance().setClassId(roomInputId);
        ClassInfo.getInstance().writeToCache(ClassroomManagerActivity.this);

        roomId = Integer.valueOf(roomInputId);

//        if (ClassInfo.getInstance().isQcloud()) {
//            PrivateMapKeyParams params = new PrivateMapKeyParams();
//            params.setIdentifier(ClassInfo.getInstance().getUserid());
//            params.setPwd("123");
//            params.setRoomNum(roomId);
//            privateMapKeyPresenter.getPrivateMapKey(params);
//            postToast("正在获取privateMapKey", true);
//        } else {
        postToast("正在进入课堂，请稍等。。。", true);
        joinClassroom(roomId, null);
//        }
    }


    /**
     * 进入课堂
     */
    private void joinClassroom(int roomId, String privateMapKey) {
        classroomPresenter.joinClassroom(roomId, privateMapKey);
    }

    private void launcherClassroomLiveActivity() {
        Intent intent = new Intent(this, ClassroomActivity.class);
        startActivity(intent);
    }

    @Override
    public void onCreateClassroomSuccess(int roomid) {
        postToast("onCreateClsssroomClick#onSuccess: " + roomid);
        this.roomId = roomid;
    }

    @Override
    public void onCreateClassFail(String module, int errCode, String errMsg) {
        postToast("onCreateClassFail#onError: errCode = " + errCode + "  description " + errMsg);
    }

    @Override
    public void onJoinClassroomSuccess(int roomid) {
        ClassInfo.getInstance().setClassId(String.valueOf(roomid));
        ClassInfo.getInstance().writeToCache(ClassroomManagerActivity.this);
        postToast("joinClassroom#onSuccess, classId: " + roomid);
        launcherClassroomLiveActivity();
    }

    @Override
    public void onJoinClassroomFail(String module, int errCode, String errMsg) {
        postToast("onJoinClassroomFail#onError: errCode = " + errCode + "  description " + errMsg);
        if (errCode == Error.ERR_NOT_AUTHENTICATION) {
            launcherClassroomLiveActivity();
        }
    }

    @Override
    public void onGetPrivateMapKeySuccess(String privateMapKey) {
        postToast("onGetPrivateMapKeySuccess::" + privateMapKey);
        postToast("正在进入课堂，请稍等。。。", true);
        joinClassroom(roomId, privateMapKey);
    }

    @Override
    public void onGetPrivateMapKeyFail(String module, int errCode, String errMsg) {
        postToast("onGetPrivateMapKeyFail: " + errCode + "  description " + errMsg);
    }

    @Override
    public void onForceOffline() {
        postToast("您已被踢下线，请检查后重新登录");
        finish();
    }

    @Override
    public void onUserSigExpired() {

    }
}
