package com.tencent.ticsdk.demo.activities;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.text.TextUtils;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.CompoundButton;
import android.widget.Spinner;
import android.widget.ToggleButton;

import com.tencent.TIMUserStatusListener;
import com.tencent.ticsdk.TICManager;
import com.tencent.ticsdk.demo.ClassInfo;
import com.tencent.ticsdk.demo.ConfigInfo;
import com.tencent.ticsdk.demo.Constants;
import com.tencent.ticsdk.demo.R;
import com.tencent.ticsdk.demo.login.LoginPresenter;
import com.tencent.ticsdk.demo.login.LoginView;
import com.tencent.ticsdk.demo.observer.UserStatusObservable;

public class LoginActivity extends BaseActvity implements LoginView, CompoundButton.OnCheckedChangeListener, TIMUserStatusListener {

    ToggleButton tbRole;
    LoginPresenter loginPresenter;

    // 测试账号信息
    Spinner spinnerAccount;

    private String identifier;
    private String userSig;

    String[] accountName;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login_layout);
        tvLog = findViewById(R.id.tv_login_log);

        tbRole = findViewById(R.id.tb_role);
        tbRole.setOnCheckedChangeListener(this);

        // 加载配置文件
        loadConfig();

        spinnerAccount = findViewById(R.id.spinner_account);
        accountName = Constants.getAccountInfo().keySet().toArray(new String[0]);
        ArrayAdapter spinnerAdapter = new ArrayAdapter<>(this, android.R.layout.simple_spinner_item, accountName);
        spinnerAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);

        spinnerAccount.setAdapter(spinnerAdapter);
        spinnerAccount.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
                identifier = accountName[position];
                userSig = Constants.getAccountInfo().get(identifier);
                ClassInfo.getInstance().setClassId(ConfigInfo.getInstance().getClassId());
            }

            @Override
            public void onNothingSelected(AdapterView<?> parent) {

            }
        });
        loginPresenter = new LoginPresenter(this);
        UserStatusObservable.getInstance().addObserver(this);
    }

    private void loadConfig(){
        try {
            ConfigInfo.getInstance().loadConfig(this);

        }catch (Exception e){
            postToast("读取配置文件失败，请在【控制台】-> 【快速上手】中生成配置内容复制到res/raw/config.json文件中", true);
        }
    }
    @Override
    protected void onStop() {
        super.onStop();
        if (isFinishing()) {
            loginPresenter.logout();
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        UserStatusObservable.getInstance().deleteObserver(this);
    }

    /**
     * 登录
     */
    public void onLoginClick(View v) {
        if (!Constants.check(this)) {
            postToast("请检查Constants里的配置是否已经填写完整。");
            return;
        }
        // 默认走的是云上环境
        //ILiveSDK.getInstance().setChannelMode(CommonConstants.E_ChannelMode.E_ChannelIMRestAPI);
        if (TextUtils.isEmpty(identifier) || TextUtils.isEmpty(userSig)){
            postToast("请检查配置文件信息是否完整。");
        }
        loginPresenter.login(identifier, userSig);
    }

    public void onLogoutClick(View v) {
        if (!Constants.check(this)) {
            postToast("请检查配置文件信息是否完整。");
            return;
        }
        loginPresenter.logout();
    }

    @Override
    public void onLoginSuccess() {
        postToast("onLoginSuccess", true);
        ClassInfo.getInstance().setUserid(identifier);
        TICManager.getInstance().setUserStatusListener(UserStatusObservable.getInstance());
        launchClassManagerActivity();
    }

    @Override
    public void onLoginError(String module, int errCode, String errMsg) {
        postToast("onLoginError#: errCode = " + errCode + "  description: " + errMsg);
    }

    @Override
    public void onLogoutSuccess() {
        postToast("onLogoutSuccess");
    }

    @Override
    public void onLogoutError(String module, int errCode, String errMsg) {
        postToast("onLogoutError#: errCode = " + errCode + "  description: " + errMsg);
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
        boolean checked = buttonView.isChecked();
        switch (buttonView.getId()) {
            case R.id.tb_role:
                ClassInfo.getInstance().setRoleTeacher(checked);
                break;
        }
    }

    private void launchClassManagerActivity() {
        Intent intent = new Intent(this, ClassroomManagerActivity.class);
        intent.addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP);
        startActivity(intent);
    }

    @Override
    public void onForceOffline() {
        postToast("您已被踢下线，请检查后重新登录", true);
    }

    @Override
    public void onUserSigExpired() {
        postToast("UserSig Expired！", true);
    }

    @Override
    public void onVerifySuccess() {
        postToast("onVerifySuccess", true);
    }

    @Override
    public void onVerifyError(String module, int errCode, String errMsg) {
        postToast("onVerifyError#: errCode = " + errCode + "  description: " + errMsg);
    }
}
