package com.tencent.ticsdk.demo.classroom;

import android.text.TextUtils;

import com.tencent.ilivesdk.ILiveCallBack;
import com.tencent.ticsdk.TICClassroomOption;
import com.tencent.ticsdk.TICManager;
import com.tencent.ticsdk.core.Error;
import com.tencent.ticsdk.demo.ClassInfo;
import com.tencent.ticsdk.demo.ConfigInfo;
import com.tencent.ticsdk.demo.Constants;
import com.tencent.ticsdk.demo.observer.ClassEventObservable;
import com.tencent.ticsdk.demo.observer.ClassroomIMObservable;

public class ClassroomPresenter {
    ClassroomView classroomView;

    public ClassroomPresenter(ClassroomView classroomView) {
        this.classroomView = classroomView;
    }

    public void createClassroom(final int roomid) {
        TICManager.getInstance().createClassroom(roomid, new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                classroomView.onCreateClassroomSuccess((Integer) data);
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                classroomView.onCreateClassFail(module, errCode, errMsg);
            }
        });
    }

    public void joinClassroom(final int roomid, String privateMapKey) {
        /**
         * 加入课堂参数配置
         */
        TICClassroomOption classroomOption = new TICClassroomOption()
                .setRoomId(roomid)
                .controlRole("user") //在参数对实时音视频的质量有较大影响，建议开发配置。；详情请移步：https://github.com/zhaoyang21cn/edu_project/blob/master/%E6%8E%A5%E5%85%A5%E6%8C%87%E5%BC%95%E6%96%87%E6%A1%A3/%E5%BC%80%E9%80%9A%E5%92%8C%E9%85%8D%E7%BD%AE%E8%85%BE%E8%AE%AF%E4%BA%91%E6%9C%8D%E5%8A%A1.md
                .autoSpeaker(false)
                .setRole(ClassInfo.getInstance().isRoleTeacher() ? TICClassroomOption.Role.TEACHER : TICClassroomOption.Role.STUDENT)
                .autoCamera(ClassInfo.getInstance().isRoleTeacher())
                .autoMic(ClassInfo.getInstance().isRoleTeacher())
                .setClassroomIMListener(ClassroomIMObservable.getInstance())
                .setClassEventListener(ClassEventObservable.getInstance());


//        if (ClassInfo.getInstance().isQcloud() && !TextUtils.isEmpty(privateMapKey)) {
//            classroomOption.privateMapKey(privateMapKey);
//        }

        TICManager.getInstance().joinClassroom(classroomOption, new ILiveCallBack() {
            @Override
            public void onSuccess(Object data) {
                classroomView.onJoinClassroomSuccess(roomid);
            }

            @Override
            public void onError(String module, int errCode, String errMsg) {
                classroomView.onJoinClassroomFail(module, errCode, errMsg);
            }
        });
    }
}
