package com.tencent.ticsdk.demo.widgets;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;

import com.tencent.boardsdk.board.WhiteboardManager;
import com.tencent.boardsdk.file.FileInfo;
import com.tencent.ticsdk.demo.R;

import java.util.Collections;
import java.util.List;
import java.util.Locale;

public class FileInfoAdapter extends RecyclerView.Adapter<FileInfoAdapter.FileInfoHolder> {
    List<FileInfo> fileInfoList;

    Context context;

    public FileInfoAdapter(Context context, List<FileInfo> fileInfos) {
        this.context = context;
        fileInfoList = fileInfos;
    }

    public void setFileInfoList(List<FileInfo> fileInfoList) {
        this.fileInfoList = fileInfoList;
        notifyDataSetChanged();
    }

    @Override
    public FileInfoHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        FileInfoHolder holder = new FileInfoHolder(LayoutInflater.from(
                context).inflate(R.layout.file_info_item, parent,
                false));
        return holder;
    }

    @Override
    public void onBindViewHolder(FileInfoHolder holder, int position) {
        final FileInfo fileInfo = fileInfoList.get(position);
        holder.setFileInfo(fileInfo);
        if (TextUtils.isEmpty(fileInfo.getFileName())) {
            holder.fileName.setText(fileInfo.getFid());
        } else {
            holder.fileName.setText(fileInfo.getFileName());
            holder.totalPages.setText(String.format(Locale.getDefault(), "Total: %d", fileInfo.getTotalPages()));
            holder.index.setText(String.format(Locale.getDefault(), "Index: %d", fileInfo.getCurrentPageIndex() + 1));
        }
        holder.btnDelete.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                WhiteboardManager.getInstance().deleteFile(Collections.singletonList(fileInfo.getFid()));
                FileInfoAdapter.this.notifyDataSetChanged();
            }
        });
    }

    @Override
    public int getItemCount() {
        return fileInfoList.size();
    }

    public static class FileInfoHolder extends RecyclerView.ViewHolder {
        FileInfo fileInfo;

        TextView fileName, totalPages, index;
        Button btnDelete;

        public FileInfoHolder(View itemView) {
            super(itemView);
            itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    WhiteboardManager.getInstance().switchFile(fileInfo.getFid());
                }
            });
            fileName = itemView.findViewById(R.id.tv_file_name);
            totalPages = itemView.findViewById(R.id.tv_total_page);
            index = itemView.findViewById(R.id.tv_page_index);
            btnDelete = itemView.findViewById(R.id.btn_delete);
        }


        public void setFileInfo(FileInfo fileInfo) {
            this.fileInfo = fileInfo;
        }
    }

}
