package com.tencent.ticsdk.demo.widgets;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.TextView;

import com.tencent.boardsdk.file.FileInfo;
import com.tencent.ticsdk.demo.R;

import java.util.List;
import java.util.Locale;

public class FileInfoSpinnerAdapter extends BaseAdapter {
    List<FileInfo> fileInfoList;

    Context context;
    LayoutInflater inflater;

    public FileInfoSpinnerAdapter(Context context, List<FileInfo> fileInfos) {
        this.context = context;
        fileInfoList = fileInfos;
        inflater = LayoutInflater.from(context);
    }

    public void setFileInfoList(List<FileInfo> fileInfoList) {
        this.fileInfoList = fileInfoList;
        notifyDataSetChanged();
    }

    @Override
    public int getCount() {
        return fileInfoList.size();
    }

    @Override
    public Object getItem(int position) {
        return fileInfoList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        FileInfoHolder viewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(context).inflate(R.layout.file_info_item, parent,
                    false);
            viewHolder = new FileInfoHolder();
            viewHolder.fileName = convertView.findViewById(R.id.tv_file_name);
            viewHolder.totalPages = convertView.findViewById(R.id.tv_total_page);
            viewHolder.index = convertView.findViewById(R.id.tv_page_index);
            viewHolder.btnDelete = convertView.findViewById(R.id.btn_delete);
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (FileInfoHolder) convertView.getTag();
        }

        viewHolder.fileName.setText(fileInfoList.get(position).getFileName());
        viewHolder.totalPages.setText(String.format(Locale.getDefault(), "Total: %d", fileInfoList.get(position).getTotalPages()));
        viewHolder.index.setText(String.format(Locale.getDefault(), "Index: %d", fileInfoList.get(position).getCurrentPageIndex()));

        return convertView;
    }

    public static class FileInfoHolder {

        TextView fileName, totalPages, index;
        Button btnDelete;

    }

}
