package com.tencent.ticsdk.demo.widgets;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.support.annotation.Nullable;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.AttributeSet;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.FrameLayout;
import android.widget.ToggleButton;

import com.tencent.boardsdk.board.WhiteboardManager;
import com.tencent.boardsdk.utils.DisplayUtil;
import com.tencent.ilivesdk.ILiveCallBack;
import com.tencent.ilivesdk.ILiveConstants;
import com.tencent.ticsdk.TICManager;
import com.tencent.ticsdk.demo.ClassInfo;
import com.tencent.ticsdk.demo.R;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public class FileOperationBar extends FrameLayout implements View.OnClickListener, CompoundButton.OnCheckedChangeListener {
    private final static String TAG = "FileOperationBar";

    ToggleButton tbCameraOpen, tbCameraSwitcher, tbMicSwitcher, tbSpeakerSwitcher;
    Button btnAddFile, deleteFile, prePage, nextPage;
    //    Spinner fileInfoListView;
    RecyclerView fileInfoListView;
    FileInfoAdapter fileInfoAdapter;

    public FileOperationBar(Context context) {
        this(context, null);
    }

    public FileOperationBar(Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public FileOperationBar(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        LayoutInflater inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        inflater.inflate(R.layout.file_operation_bar, this);


        tbCameraOpen = findViewById(R.id.tb_camera_open);
        tbCameraOpen.setChecked(ClassInfo.getInstance().isRoleTeacher());
        tbCameraOpen.setOnCheckedChangeListener(this);

        tbCameraSwitcher = findViewById(R.id.tb_camera_switcher);
        tbCameraSwitcher.setOnCheckedChangeListener(this);

        tbMicSwitcher = findViewById(R.id.tb_mic_switcher);
        tbMicSwitcher.setChecked(ClassInfo.getInstance().isRoleTeacher());
        tbMicSwitcher.setOnCheckedChangeListener(this);

        tbSpeakerSwitcher = findViewById(R.id.tb_speaker_switcher);
        tbSpeakerSwitcher.setOnCheckedChangeListener(this);

        btnAddFile = findViewById(R.id.btn_add_page);
        deleteFile = findViewById(R.id.btn_delete_page);
        prePage = findViewById(R.id.btn_pre_page);
        nextPage = findViewById(R.id.btn_next_page);

        btnAddFile.setOnClickListener(this);
        deleteFile.setOnClickListener(this);
        prePage.setOnClickListener(this);
        nextPage.setOnClickListener(this);

        fileInfoListView = findViewById(R.id.file_list);
        fileInfoListView.addItemDecoration(new SimpleDividerItemDecoration(context));

        fileInfoListView.setLayoutManager(new LinearLayoutManager(context));
        fileInfoAdapter = new FileInfoAdapter(context, WhiteboardManager.getInstance().getAllFileInfo());
        fileInfoListView.setAdapter(fileInfoAdapter);
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
        boolean on = buttonView.isChecked();
        switch (buttonView.getId()) {

            case R.id.tb_camera_open:
                TICManager.getInstance().enableCamera(ILiveConstants.FRONT_CAMERA, on, new ILiveCallBack() {
                    @Override
                    public void onSuccess(Object data) {
                        Log.i(TAG, "enableCamera#onSuccess: " + data);
                    }

                    @Override
                    public void onError(String module, int errCode, String errMsg) {
                        Log.i(TAG, "enableCamera#onError: errCode = " + errCode + "  description " + errMsg);
                    }
                });

                break;
            case R.id.tb_camera_switcher:
                TICManager.getInstance().switchCamera(new ILiveCallBack() {
                    @Override
                    public void onSuccess(Object data) {
                        Log.i(TAG, "switchCamera#onSuccess: " + data);
                    }

                    @Override
                    public void onError(String module, int errCode, String errMsg) {
                        Log.i(TAG, "switchCamera#onError: errCode = " + errCode + "  description " + errMsg);
                    }
                });
                break;
            case R.id.tb_mic_switcher:
                TICManager.getInstance().enableMic(on, new ILiveCallBack() {
                    @Override
                    public void onSuccess(Object data) {
                        Log.i(TAG, "enableMic#onSuccess: " + data);
                    }

                    @Override
                    public void onError(String module, int errCode, String errMsg) {
                        Log.i(TAG, "enableMic#onError: errCode = " + errCode + "  description " + errMsg);
                    }
                });
                break;
            case R.id.tb_speaker_switcher:
                TICManager.getInstance().enableSpeaker(on, new ILiveCallBack() {
                    @Override
                    public void onSuccess(Object data) {
                        Log.i(TAG, "enableSpeaker#onSuccess: " + data);
                    }

                    @Override
                    public void onError(String module, int errCode, String errMsg) {
                        Log.i(TAG, "enableSpeaker#onError: errCode = " + errCode + "  description " + errMsg);
                    }
                });
                break;
        }
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.btn_add_page:
                String boardId = WhiteboardManager.getInstance().createSubBoard();
                Log.i(TAG, "onClick: " + boardId);
                break;
            case R.id.btn_delete_page:
                String deleteboardId = WhiteboardManager.getInstance().getCurrentWhiteboardId();
                List<String> deleteIds = new ArrayList<>();
                deleteIds.add(deleteboardId);
                WhiteboardManager.getInstance().deleteBoardById(deleteIds);
                break;
            case R.id.btn_pre_page:
                WhiteboardManager.getInstance().prePage();
                break;
            case R.id.btn_next_page:
                WhiteboardManager.getInstance().nextPage();
                break;
        }
        updateFileInfo();
    }

    public void updateFileInfo(){
        fileInfoAdapter.setFileInfoList(WhiteboardManager.getInstance().getAllFileInfo());
        fileInfoAdapter.notifyDataSetChanged();
    }

    public class SimpleDividerItemDecoration extends RecyclerView.ItemDecoration {
        private Drawable mDivider;

        public SimpleDividerItemDecoration(Context context) {
            mDivider = context.getResources().getDrawable(R.drawable.divider);
        }

        @Override
        public void onDrawOver(Canvas c, RecyclerView parent, RecyclerView.State state) {
            int left = parent.getPaddingLeft();
            int right = parent.getWidth() - parent.getPaddingRight();

            int childCount = parent.getChildCount();
            for (int i = 0; i < childCount; i++) {
                View child = parent.getChildAt(i);

                RecyclerView.LayoutParams params = (RecyclerView.LayoutParams) child.getLayoutParams();

                int top = child.getBottom() + params.bottomMargin;
                int bottom = top + mDivider.getIntrinsicHeight();
                int padding = DisplayUtil.dip2px(getContext(), 15);
                mDivider.setBounds(left + padding, top, right - padding, bottom);
                mDivider.draw(c);
            }
        }
    }
}
