package com.tencent.ticsdk.demo.widgets;

import android.content.Context;
import android.graphics.Color;
import android.widget.RadioButton;
import android.widget.RadioGroup;

import com.tencent.boardsdk.board.WhiteboardManager;
import com.tencent.boardsdk.config.TextConfig;
import com.tencent.ticsdk.demo.R;

import java.util.HashMap;
import java.util.Map;

public class TextConfigDialog extends BaseDialog implements RadioGroup.OnCheckedChangeListener {
    RadioGroup rgTextSize, rtTextStyle, rgTextColoe;

    HashMap<Integer, Integer> sizeMapper = new HashMap<>();
    HashMap<Integer, Integer> colorMapper = new HashMap<>();
    HashMap<Integer, Integer> styleMapper = new HashMap<>();

    public TextConfigDialog(Context context, int themeResId) {
        super(context, themeResId);
        setContentView(R.layout.text_config_panel_layout);
        initMapper();
        initRadioGroup();

        rgTextSize = findViewById(R.id.radio_group_text_size);
        rgTextSize.setOnCheckedChangeListener(this);

        rtTextStyle = findViewById(R.id.radio_group_text_style);
        rtTextStyle.setOnCheckedChangeListener(this);

        rgTextColoe = findViewById(R.id.radio_group_text_color);
        rgTextColoe.setOnCheckedChangeListener(this);
    }

    private void initMapper() {
        sizeMapper.put(R.id.rb_text_size_small, TextConfig.TEXT_SIZE_SMALL);
        sizeMapper.put(R.id.rb_text_size_medium, TextConfig.TEXT_SIZE_MEDIUM);
        sizeMapper.put(R.id.rb_text_size_large, TextConfig.TEXT_SIZE_LARGE);

        styleMapper.put(R.id.rb_text_bold_style, TextConfig.TEXT_STYLE_BOLD);
        styleMapper.put(R.id.rb_text_italic_style, TextConfig.TEXT_STYLE_ITALIC);

        colorMapper.put(R.id.rb_text_color_blue, Color.BLUE);
        colorMapper.put(R.id.rb_text_color_green, Color.GREEN);
        colorMapper.put(R.id.rb_text_color_yellow, Color.YELLOW);
        colorMapper.put(R.id.rb_text_color_red, Color.RED);
        colorMapper.put(R.id.rb_text_color_black, Color.BLACK);
        colorMapper.put(R.id.rb_text_color_gray, Color.GRAY);
    }

    private void initRadioGroup() {

        int size = WhiteboardManager.getInstance().getConfig().getTextSize();
        for (Map.Entry<Integer, Integer> entry : sizeMapper.entrySet()) {
            if (size == entry.getValue()) {
                RadioButton radioButton = findViewById(entry.getKey());
                radioButton.setChecked(true);
            }
        }

        int color = WhiteboardManager.getInstance().getConfig().getPaintColor();
        for (Map.Entry<Integer, Integer> entry : colorMapper.entrySet()) {
            if (color == entry.getValue()) {
                RadioButton radioButton = findViewById(entry.getKey());
                radioButton.setChecked(true);
            }
        }
    }

    @Override
    public void onCheckedChanged(RadioGroup group, int checkedId) {
        RadioButton radioButton = findViewById(checkedId);
        radioButton.setChecked(true);
        switch (group.getId()) {
            case R.id.radio_group_text_size:
                onSizeSelected(checkedId);
                break;
            case R.id.radio_group_text_color:
                onColorSelected(checkedId);
                break;
            case R.id.radio_group_text_style:
                onStyleSelected(checkedId);
                break;
        }
    }

    private void onSizeSelected(int checkedId) {
        WhiteboardManager.getInstance().setTextSize(sizeMapper.get(checkedId));
    }

    private void onColorSelected(int checkedId) {
        WhiteboardManager.getInstance().setTextColor(colorMapper.get(checkedId));
    }

    private void onStyleSelected(int checkedId) {
        WhiteboardManager.getInstance().setTextStyle(styleMapper.get(checkedId));

    }
}
