package com.tencent.ticsdk.demo.widgets;

import android.content.Context;
import android.graphics.Color;
import android.graphics.Paint;
import android.view.View;
import android.widget.ImageButton;
import android.widget.RadioButton;
import android.widget.RadioGroup;

import com.tencent.boardsdk.board.WhiteboardManager;
import com.tencent.boardsdk.config.PaintType;
import com.tencent.ticsdk.demo.R;

import java.util.HashMap;
import java.util.Map;

public class WhiteboardDrawToolBarDialog extends BaseDialog implements RadioGroup.OnCheckedChangeListener {
    RadioGroup radioGroupSize, radioGroupShape, radioGroupColor, radioGroupBgColor, radioGroupGlobalColor;

    ImageButton tbExit;
    HashMap<Integer, Integer> sizeMapper = new HashMap<>();
    HashMap<Integer, PaintType> shapeMapper = new HashMap<>();
    HashMap<Integer, Integer> colorMapper = new HashMap<>();

    public WhiteboardDrawToolBarDialog(Context context, int themeResId) {
        super(context, themeResId);
        setContentView(R.layout.whiteboard_draw_panel_layout);
        initMapper();
        initRadioGroup();
        radioGroupSize = findViewById(R.id.radio_group_size);
        radioGroupShape = findViewById(R.id.radio_group_shape);
        radioGroupColor = findViewById(R.id.radio_group_color);
        radioGroupBgColor = findViewById(R.id.radio_current_group_color);
        radioGroupGlobalColor = findViewById(R.id.radio_global_group_color);
        radioGroupSize.setOnCheckedChangeListener(this);
        radioGroupShape.setOnCheckedChangeListener(this);
        radioGroupColor.setOnCheckedChangeListener(this);
        radioGroupBgColor.setOnCheckedChangeListener(this);
        radioGroupGlobalColor.setOnCheckedChangeListener(this);


        tbExit = findViewById(R.id.ib_exit);
        tbExit.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                WhiteboardDrawToolBarDialog.this.dismiss();
            }
        });
    }

    private void initMapper() {
        sizeMapper.put(R.id.iv_pen_size_small, 3);
        sizeMapper.put(R.id.iv_pen_size_medium, 6);
        sizeMapper.put(R.id.iv_pen_size_large, 9);

        shapeMapper.put(R.id.iv_shape_path, PaintType.PATH);
        shapeMapper.put(R.id.iv_shape_line, PaintType.LINE);
        shapeMapper.put(R.id.iv_shape_stroke_rect, PaintType.RECT);
        shapeMapper.put(R.id.iv_shape_fill_rect, PaintType.RECT);
        shapeMapper.put(R.id.iv_shape_stroke_oval, PaintType.CIRCLE);
        shapeMapper.put(R.id.iv_shape_fill_oval, PaintType.CIRCLE);

        colorMapper.put(R.id.iv_pen_color_blue, Color.BLUE);
        colorMapper.put(R.id.iv_pen_color_green, Color.GREEN);
        colorMapper.put(R.id.iv_pen_color_yellow, Color.YELLOW);
        colorMapper.put(R.id.iv_pen_color_red, Color.RED);
        colorMapper.put(R.id.iv_pen_color_black, Color.BLACK);
        colorMapper.put(R.id.iv_pen_color_gray, Color.GRAY);

        colorMapper.put(R.id.iv_current_bg_color_blue, Color.BLUE);
        colorMapper.put(R.id.iv_current_bg_color_green, Color.GREEN);
        colorMapper.put(R.id.iv_current_bg_color_yellow, Color.YELLOW);
        colorMapper.put(R.id.iv_current_bg_color_red, Color.RED);
        colorMapper.put(R.id.iv_current_bg_color_black, Color.BLACK);
        colorMapper.put(R.id.iv_current_bg_color_gray, Color.GRAY);

        colorMapper.put(R.id.iv_global_bg_color_blue, Color.BLUE);
        colorMapper.put(R.id.iv_global_bg_color_green, Color.GREEN);
        colorMapper.put(R.id.iv_global_bg_color_yellow, Color.YELLOW);
        colorMapper.put(R.id.iv_global_bg_color_red, Color.RED);
        colorMapper.put(R.id.iv_global_bg_color_black, Color.BLACK);
        colorMapper.put(R.id.iv_global_bg_color_gray, Color.GRAY);
    }

    private void initRadioGroup() {
        int size = WhiteboardManager.getInstance().getConfig().getPaintSize();
        for (Map.Entry<Integer, Integer> entry : sizeMapper.entrySet()) {
            if (size == entry.getValue()) {
                RadioButton radioButton = findViewById(entry.getKey());
                radioButton.setChecked(true);
            }
        }

        int color = WhiteboardManager.getInstance().getConfig().getPaintColor();
        for (Map.Entry<Integer, Integer> entry : colorMapper.entrySet()) {
            if (color == entry.getValue()) {
                RadioButton radioButton = findViewById(entry.getKey());
                radioButton.setChecked(true);
            }
        }
        //WhiteboardManager.getInstance().setGlobalBackgroundColor(Color.WHITE);

        PaintType shape = WhiteboardManager.getInstance().getConfig().getPaintType();
        Paint.Style fillType = WhiteboardManager.getInstance().getConfig().getStyle();
        int viewId;
        if (shape == PaintType.RECT) {
            if (fillType == Paint.Style.FILL) {
                viewId = R.id.iv_shape_fill_rect;
            } else {
                viewId = R.id.iv_shape_stroke_rect;
            }
        } else if (shape == PaintType.CIRCLE) {
            if (fillType == Paint.Style.FILL) {
                viewId = R.id.iv_shape_fill_oval;
            } else {
                viewId = R.id.iv_shape_stroke_oval;
            }
        } else if (shape == PaintType.LINE) {
            viewId = R.id.iv_shape_line;
        } else {
            viewId = R.id.iv_shape_path;
        }
        RadioButton radioButton = findViewById(viewId);
        radioButton.setChecked(true);
    }

    @Override
    public void onCheckedChanged(RadioGroup group, int checkedId) {
        RadioButton radioButton = findViewById(checkedId);
        radioButton.setChecked(true);
        switch (group.getId()) {
            case R.id.radio_group_size:
                onSizeSelected(checkedId);
                break;
            case R.id.radio_group_shape:
                onShapeSelected(checkedId);
                break;
            case R.id.radio_group_color:
                onColorSelect(checkedId);
                break;
            case R.id.radio_current_group_color:
                WhiteboardManager.getInstance().setBackgroundColor(colorMapper.get(checkedId));
                break;
            case R.id.radio_global_group_color:
                //WhiteboardManager.getInstance().setGlobalBackgroundColor(colorMapper.get(checkedId));
                WhiteboardManager.getInstance().setTextColor(colorMapper.get(checkedId));
                break;
        }
    }

    private void onSizeSelected(int checkedId) {
        WhiteboardManager.getInstance().setPaintSize(sizeMapper.get(checkedId));
    }

    private void onShapeSelected(int checkedId) {
        WhiteboardManager.getInstance().setPaintType(shapeMapper.get(checkedId));
        switch (checkedId) {
            case R.id.iv_shape_fill_rect:
            case R.id.iv_shape_fill_oval:
                WhiteboardManager.getInstance().setFillStyle(Paint.Style.FILL);
                break;
            case R.id.iv_shape_stroke_rect:
            case R.id.iv_shape_stroke_oval:
                WhiteboardManager.getInstance().setFillStyle(Paint.Style.STROKE);
                break;
        }
    }

    private void onColorSelect(int checkedId) {
        WhiteboardManager.getInstance().setPaintColor(colorMapper.get(checkedId));
    }
}
