package com.tencent.ticsdk.demo.widgets;

import android.content.Context;
import android.content.DialogInterface;
import android.support.annotation.Nullable;
import android.util.AttributeSet;
import android.view.Display;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.LinearLayout;
import android.widget.RadioButton;

import com.tencent.boardsdk.board.IWbCallBack;
import com.tencent.boardsdk.board.WhiteboardManager;
import com.tencent.boardsdk.config.PaintType;
import com.tencent.ticsdk.demo.R;

/**
 * Created by eric on 2018/3/2.
 */

public class WhiteboardToolBar extends LinearLayout implements View.OnClickListener {
    private final static String TAG = "WhiteboardToolBar";
    Context context;

    private final static String NET_URL = "http://upload.wikimedia.org/wikipedia/commons/9/9d/Rafthouses_in_Khao_Sok_national_park.jpg";

    RadioButton rbPen, rbRevoke, rvRedo, rbPointSelect, rbBoxSelect, rbFile, rbClear, rbClearAll, rbClearBitmap, rbClearDrawByFids;
    RadioButton rbNetPicture, rbEraser, rbText, rbLaser;

    PaintType lastPaintType = PaintType.PATH;

    WhiteboardDrawToolBarDialog drawParamsDialog;
    TextConfigDialog textConfigDialog;

    FilePickerClickListener filePickerClickListener;

    public WhiteboardToolBar(Context context) {
        this(context, null);
    }

    public WhiteboardToolBar(Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public WhiteboardToolBar(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.context = context;
        LayoutInflater inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        inflater.inflate(R.layout.whiteboard_tool_bar_layout, this);

        rbPen = findViewById(R.id.rb_pen);
        rbRevoke = findViewById(R.id.rb_revoke);
        rvRedo = findViewById(R.id.rb_redo);
        rbPointSelect = findViewById(R.id.rb_point_select);
        rbBoxSelect = findViewById(R.id.rb_box_select);
        rbFile = findViewById(R.id.rb_file);
        rbClear = findViewById(R.id.rb_clearAll);
        rbClearAll = findViewById(R.id.rb_clear);
        rbClearBitmap = findViewById(R.id.rb_clearBackgroundBitmap);
        rbClearDrawByFids = findViewById(R.id.rb_clear_draws_by_fid);
        rbNetPicture = findViewById(R.id.rb_network_picture);
        rbEraser = findViewById(R.id.rb_eraser);
        rbText = findViewById(R.id.rb_text);
        rbLaser = findViewById(R.id.rb_laser);

        rbPen.setOnClickListener(this);
        rbRevoke.setOnClickListener(this);
        rvRedo.setOnClickListener(this);
        rbPointSelect.setOnClickListener(this);
        rbBoxSelect.setOnClickListener(this);
        rbFile.setOnClickListener(this);
        rbClear.setOnClickListener(this);
        rbClearAll.setOnClickListener(this);
        rbClearBitmap.setOnClickListener(this);
        rbClearDrawByFids.setOnClickListener(this);
        rbNetPicture.setOnClickListener(this);
        rbEraser.setOnClickListener(this);
        rbText.setOnClickListener(this);
        rbLaser.setOnClickListener(this);

        initDialog();
    }

    private void initDialog() {
        drawParamsDialog = new WhiteboardDrawToolBarDialog(context, R.style.invitedialog);
        Window window = drawParamsDialog.getWindow();
        Display display = drawParamsDialog.getWindow().getWindowManager().getDefaultDisplay();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.width = (int) (display.getWidth() * 0.8f);
        drawParamsDialog.getWindow().setAttributes(attributes);

        drawParamsDialog.setOnDismissListener(new DialogInterface.OnDismissListener() {
            @Override
            public void onDismiss(DialogInterface dialog) {
                lastPaintType = WhiteboardManager.getInstance().getConfig().getPaintType();
            }
        });


        textConfigDialog = new TextConfigDialog(context, R.style.invitedialog);
        Window textwindow = drawParamsDialog.getWindow();
        Display textdisplay = drawParamsDialog.getWindow().getWindowManager().getDefaultDisplay();
        WindowManager.LayoutParams textattributes = textwindow.getAttributes();
        textattributes.width = (int) (textdisplay.getWidth() * 0.8f);
        textConfigDialog.getWindow().setAttributes(textattributes);

        textConfigDialog.setOnDismissListener(new DialogInterface.OnDismissListener() {
            @Override
            public void onDismiss(DialogInterface dialog) {

            }
        });



    }

    public void setFilePickerClickListener(FilePickerClickListener filePickerClickListener) {
        this.filePickerClickListener = filePickerClickListener;
    }

    @Override
    public void onClick(View v) {
        ((RadioButton) v).setChecked(true);
        switch (v.getId()) {
            case R.id.rb_revoke:
                onRevokeClick();
                break;
            case R.id.rb_redo:
                onRedoClick();
                break;
            case R.id.rb_pen:
                onPenClick();
                break;
            case R.id.rb_point_select:
                onPointSelectClick();
                break;
            case R.id.rb_eraser:
                onEraseClick();
                break;
            case R.id.rb_box_select:
                onBoxSelectClick();
                break;
            case R.id.rb_file:
                onFileClick();
                break;
            case R.id.rb_clear:
                onClearClick();
                break;
            case R.id.rb_clearAll:
                onClearAllClick();
                break;
            case R.id.rb_clearBackgroundBitmap:
                onClearBitmap();
                break;
            case R.id.rb_clear_draws_by_fid:
                onClearDrawsByFids();
                break;
            case R.id.rb_network_picture:
//                WhiteboardManager.getInstance().addFile("/sdcard/Python入门.ppt", new IWbProgressCallBack<FileInfo>() {
//                    @Override
//                    public void onPrgress(int percent) {
//
//                    }
//
//                    @Override
//                    public void onSuccess(FileInfo data) {
//
//                    }
//
//                    @Override
//                    public void onError(String module, int errCode, String errMsg) {
//
//                    }
//                });
                // onSetNetPictureAsBackground();
                break;
            case R.id.rb_text:
                onTextDraw();
                break;
            case R.id.rb_laser:
                WhiteboardManager.getInstance().setPaintType(PaintType.LASER);
                break;
        }
    }

    private void onPenClick() {
        WhiteboardManager.getInstance().setPaintType(lastPaintType);
        showDrawParamsDialog();
    }

    private void onRevokeClick() {
        WhiteboardManager.getInstance().undo();
    }

    private void onRedoClick() {
        WhiteboardManager.getInstance().redo();
    }

    private void onEraseClick() {
        WhiteboardManager.getInstance().setPaintType(PaintType.LINE_ERASER);
    }

    private void onPointSelectClick() {
        switch (WhiteboardManager.getInstance().getConfig().getPaintType()) {
            case LINE:
            case PATH:
            case RECT:
            case CIRCLE:
                lastPaintType = WhiteboardManager.getInstance().getConfig().getPaintType();
                break;
            case LINE_ERASER:
            case BOX_SELECTOR:
            case POINT_SELECTOR:
        }
        WhiteboardManager.getInstance().setPaintType(PaintType.POINT_SELECTOR);
    }

    private void onBoxSelectClick() {
        switch (WhiteboardManager.getInstance().getConfig().getPaintType()) {
            case LINE:
            case PATH:
            case RECT:
            case CIRCLE:
                lastPaintType = WhiteboardManager.getInstance().getConfig().getPaintType();
                break;
            case LINE_ERASER:
            case BOX_SELECTOR:
            case POINT_SELECTOR:
        }
        WhiteboardManager.getInstance().setPaintType(PaintType.BOX_SELECTOR);
    }

    private void onFileClick() {
        showFilePickerDialog();
    }

    private void onClearClick() {
        //WhiteboardManager.getInstance().clear(true);
        WhiteboardManager.getInstance().clearDraws();
    }

    private void onClearAllClick() {
        //WhiteboardManager.getInstance().clear(true);
        WhiteboardManager.getInstance().clear();
    }

    private void onClearBitmap() {
        //WhiteboardManager.getInstance().clear(true);
        WhiteboardManager.getInstance().setBoardBackGround(null, null, null);
    }

    private void onClearDrawsByFids() {
        WhiteboardManager.getInstance().clearFileDraws(WhiteboardManager.getInstance().getFidList());
    }

    private void onTextDraw() {
        WhiteboardManager.getInstance().setPaintType(PaintType.TEXT);
        showTextConfigDlg();
    }

    private void onSetNetPictureAsBackground() {
        //WhiteboardManager.getInstance().clear(true);
        WhiteboardManager.getInstance().setBoardBackGround(NET_URL, true, new IWbCallBack<String>() {
            @Override
            public void onSuccess(String data) {

            }

            @Override
            public void onError(String module, int errCode, String errMsg) {

            }
        });

    }

    private void showDrawParamsDialog() {
        if (drawParamsDialog.isShowing()) {
            return;
        }
        drawParamsDialog.show();
    }

    private void showTextConfigDlg(){
        if (textConfigDialog.isShowing()) {
            return;
        }
        textConfigDialog.show();
    }

    private void showFilePickerDialog() {

        FilePickerDialog filePickerDialog = new FilePickerDialog(context, R.style.invitedialog, filePickerClickListener);
        Window window = filePickerDialog.getWindow();
        Display display = window.getWindowManager().getDefaultDisplay();
        WindowManager.LayoutParams filePickerDialogWindowAttributes = window.getAttributes();
        window.setGravity(Gravity.BOTTOM);
        filePickerDialogWindowAttributes.width = display.getWidth();

        filePickerDialog.getWindow().setAttributes(filePickerDialogWindowAttributes);
        filePickerDialog.setCanceledOnTouchOutside(true);
        filePickerDialog.setCancelable(true);
        filePickerDialog.show();
    }

    public interface FilePickerClickListener {
        void onFilePickerClick(int type);
    }

}
